@@ -13,11 +13,11 @@ Finance::Bank::ID::BCA - Check your BCA accounts from Perl
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 =head1 SYNOPSIS
@@ -27,7 +27,7 @@ our $VERSION = '0.02';
     # FBI::BCA uses Log4perl. the easiest way to show logs is with these 2 lines:
     use Log::Log4perl qw(:easy);
     Log::Log4perl->easy_init($DEBUG);
-    
+
     my $ibank = Finance::Bank::ID::BCA->new(
         username => 'ABCDEFGH1234', # optional if you're only using parse_statement()
         password => '123456',       # idem
@@ -96,10 +96,10 @@ GUARANTEE>, explicit or implied.
 
 Most methods die() when encountering errors, so you can use eval() to trap them.
 
-This module uses Log::Log4perl, so you can see more debugging statements on 
+This module uses Log::Log4perl, so you can see more debugging statements on
 your screen, log files, etc.
 
-Full response headers and bodies are dumped to a separate logger. See 
+Full response headers and bodies are dumped to a separate logger. See
 documentation on C<new()> below and the sample script in examples/ subdirectory
 in the distribution.
 
@@ -182,7 +182,7 @@ Dies on failure.
 sub login {
     my ($self) = @_;
     my $s = $self->site;
-    
+
     return 1 if $self->logged_in;
     die "400 Username not supplied" unless $self->username;
     die "400 Password not supplied" unless $self->password;
@@ -235,10 +235,10 @@ sub _menu {
     my $s = $self->site;
     $self->_req(get => ["$s/nav_bar_indo/account_information_menu.htm"]);
 }
-    
+
 =head2 list_accounts()
 
-Return an array containing all account numbers that are associated with the 
+Return an array containing all account numbers that are associated with the
 current net banking login.
 
 =cut
@@ -253,7 +253,7 @@ sub list_accounts {
 sub _check_balances {
     my ($self) = @_;
     my $s = $self->site;
-    
+
     my $re = qr!
 <tr>\s*
   <td[^>]+>\s*<div[^>]+>\s*<font[^>]+>\s*(\d+)\s*</font>\s*</div>\s*</td>\s*
@@ -272,19 +272,19 @@ sub _check_balances {
                     '';
                 }
     );
-    
+
     my @res;
     my $content = $self->mech->content;
     while ($content =~ m/$re/og) {
-        push @res, { account => $1, 
-                     account_type => $2, 
+        push @res, { account => $1,
+                     account_type => $2,
                      currency => $3,
                      balance => $self->_stripD($4) + 0.01*$5,
                  };
     }
     @res;
 }
-    
+
 =head2 check_balance([$account])
 
 Return balance for specified account, or the default account if C<$account> is
@@ -420,7 +420,7 @@ sub get_statement {
             }
         }
     }
-        
+
     $self->_req(submit_form => [
                                 form_number => 1,
                                 fields => {
@@ -510,7 +510,7 @@ sub _ps_get_metadata {
         return "can't get currency, $adv1";
     }
     $stmt->{currency} = ($1 eq 'Rp' ? 'IDR' : $1);
-    
+
     unless ($page =~ /(?:^|>)(?:Nama|Name)\s*(?:<[^>]+>\s*)*[:\t]\s*(?:<[^>]+>\s*)*([^<\015\012]+)/m) {
         return "can't get account holder, $adv1";
     }
@@ -535,7 +535,19 @@ sub _ps_get_transactions {
 
     my @e;
     # text version
-    while ($page =~ m!^(\d\d/\d\d| ?PEND| ?NEXT)\s*\t\s*((?:[^\t]|\n)*?)\s*\t\s*(\d{4})\s*\t\s*([0-9,]+)\.(\d\d)\s*\t?\s*(CR|DB)\s*\t\s*([0-9,]+)\.(\d\d)!mg) {
+    while ($page =~ m!^
+(\d\d/\d\d|\s?PEND|\s?NEXT)
+  (?:\s*\t\s*|\n)
+((?:[^\t]|\n)*?)
+  (?:\s*\t\s*|\n)
+(\d{4})
+  (?:\s*\t\s*|\n)
+([0-9,]+)\.(\d\d)
+  (?:\s*\t?\s*|\n)
+(CR|DB)
+  (?:\s*\t\s*|\n)
+([0-9,]+)\.(\d\d)
+    !mxg) {
         push @e, {date=>$1, desc=>$2, br=>$3, amt=>$4, amtf=>$5, crdb=>$6, bal=>$7, balf=>$8};
     }
     if (!@e) {
@@ -598,10 +610,12 @@ sub _ps_get_transactions {
 
         if ($self->_variant eq 'perorangan' &&
             $tx->{date}->dow =~ /6|7/ &&
-            $tx->{description} !~ /^(BUNGA|CR KOREKSI BUNGA|PAJAK BUNGA)$/) {
+            $tx->{description} !~ /^(BIAYA ADM|BUNGA|CR KOREKSI BUNGA|PAJAK BUNGA)$/) {
             return "check failed in tx#$i: In KlikBCA Perorangan, all ".
-                "transactions must not be in Sat/Sun except for Interest";
-            # note: in KlikBCA perorangan, BIAYA ADM is set on Fridays
+                "transactions must not be in Sat/Sun except for Interest and ".
+                "Admin Fee";
+            # note: in Tahapan perorangan, BIAYA ADM is set on
+            # Fridays, but for Tapres (?) on last day of the month
         }
 
         if ($self->_variant eq 'bisnis' &&
